summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRoshan Pius <rpius@google.com>2016-03-17 22:21:26 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2016-03-17 22:21:27 +0000
commit35f09e58ea5b9a31c2118b708f032dc7741caf64 (patch)
tree5e3de54babafc8c574d2cbd3b4d208e5fa430abe
parentfbcd1f10a9e47b890a1af6df2040c1ba7ba7ee34 (diff)
parent84d0d10bc29d7823f376ac8ccf111a53b50aa90e (diff)
downloadlibhardware_legacy-35f09e58ea5b9a31c2118b708f032dc7741caf64.tar.gz
Merge "Add tx time per level stats in radio_stat" into nyc-dev
-rw-r--r--include/hardware_legacy/link_layer_stats.h27
1 files changed, 15 insertions, 12 deletions
diff --git a/include/hardware_legacy/link_layer_stats.h b/include/hardware_legacy/link_layer_stats.h
index c6202ad..281e6e5 100644
--- a/include/hardware_legacy/link_layer_stats.h
+++ b/include/hardware_legacy/link_layer_stats.h
@@ -84,18 +84,21 @@ typedef struct {
/* radio statistics */
typedef struct {
- wifi_radio radio; // wifi radio (if multiple radio supported)
- u32 on_time; // msecs the radio is awake (32 bits number accruing over time)
- u32 tx_time; // msecs the radio is transmitting (32 bits number accruing over time)
- u32 rx_time; // msecs the radio is in active receive (32 bits number accruing over time)
- u32 on_time_scan; // msecs the radio is awake due to all scan (32 bits number accruing over time)
- u32 on_time_nbd; // msecs the radio is awake due to NAN (32 bits number accruing over time)
- u32 on_time_gscan; // msecs the radio is awake due to G?scan (32 bits number accruing over time)
- u32 on_time_roam_scan; // msecs the radio is awake due to roam?scan (32 bits number accruing over time)
- u32 on_time_pno_scan; // msecs the radio is awake due to PNO scan (32 bits number accruing over time)
- u32 on_time_hs20; // msecs the radio is awake due to HS2.0 scans and GAS exchange (32 bits number accruing over time)
- u32 num_channels; // number of channels
- wifi_channel_stat channels[]; // channel statistics
+ wifi_radio radio; // wifi radio (if multiple radio supported)
+ u32 on_time; // msecs the radio is awake (32 bits number accruing over time)
+ u32 tx_time; // msecs the radio is transmitting (32 bits number accruing over time)
+ u32 num_tx_levels; // number of radio transmit power levels
+ u32 *tx_time_per_levels; // pointer to an array of radio transmit per power levels in
+ // msecs accured over time
+ u32 rx_time; // msecs the radio is in active receive (32 bits number accruing over time)
+ u32 on_time_scan; // msecs the radio is awake due to all scan (32 bits number accruing over time)
+ u32 on_time_nbd; // msecs the radio is awake due to NAN (32 bits number accruing over time)
+ u32 on_time_gscan; // msecs the radio is awake due to G?scan (32 bits number accruing over time)
+ u32 on_time_roam_scan; // msecs the radio is awake due to roam?scan (32 bits number accruing over time)
+ u32 on_time_pno_scan; // msecs the radio is awake due to PNO scan (32 bits number accruing over time)
+ u32 on_time_hs20; // msecs the radio is awake due to HS2.0 scans and GAS exchange (32 bits number accruing over time)
+ u32 num_channels; // number of channels
+ wifi_channel_stat channels[]; // channel statistics
} wifi_radio_stat;
/**